var Ref = /*#__PURE__*/function () {
  "use strict";

  function Ref() {
    var ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Ref;
    babelHelpers.classCallCheck(this, Ref);
    this.ref = ref;
  }

  return Ref;
}();

var X = /*#__PURE__*/function () {
  "use strict";

  function X() {
    var x = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : foo;
    babelHelpers.classCallCheck(this, X);
    this.x = x;
  }

  return X;
}();
